# coding: utf-8
from sqlalchemy import PrimaryKeyConstraint, Column, DateTime, Float, ForeignKey, Integer, text
from sqlalchemy.orm import relationship
from sqlalchemy.sql.sqltypes import NullType
from sqlalchemy.dialects.postgresql import JSONB
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()
metadata = Base.metadata


class Data(Base):
    """                         Table "public.data"  
        Column     |           Type           | Collation | Nullable | Default  
    ---------------+--------------------------+-----------+----------+---------  
     datetime      | timestamp with time zone |           | not null |  
     value         | double precision         |           | not null |  
     flags         | integer                  |           | not null |  
     timeseries_id | integer                  |           | not null |  
    Indexes:  
     "data_pkey" PRIMARY KEY, btree (timeseries_id, datetime)  
     "data_datetime_idx" btree (datetime)  
     "data_timeseries_id_idx" btree (timeseries_id)  
     "data_value_idx" btree (value)  
    Check constraints:  
     "data_flags_check" CHECK (flags >= 0)  
    Foreign-key constraints:  
     "data_timeseries_id_fkey" FOREIGN KEY (timeseries_id) REFERENCES timeseries(id)  
    """
    __tablename__ = 'data'
    __table_args__ = (
                        PrimaryKeyConstraint('timeseries_id', 'datetime'),
                     )

    datetime = Column(DateTime(True), nullable=False, index=True)
    value = Column(Float(53), nullable=False, index=True)
    flags = Column(Integer, nullable=False)
    timeseries_id = Column(ForeignKey('timeseries.id', deferrable=True, initially='DEFERRED'), nullable=False, index=True)
